@@ -1014,7 +1014,6 @@ public void setText (String string) {
 	info.cbSize = MENUITEMINFO.sizeof;
 	long hMenu = parent.handle;
 
-	/* Use the character encoding for the default locale */
 	TCHAR buffer = new TCHAR (0, string, true);
 	int byteCount = buffer.length () * TCHAR.sizeof;
 	pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
@@ -1168,9 +1167,7 @@ LRESULT wmMeasureChild (long wParam, long lParam) {
 		long hMenu = parent.handle;
 		OS.GetMenuInfo (hMenu, lpcmi);
 		if ((lpcmi.dwStyle & OS.MNS_CHECKORBMP) == 0) {
-			MenuItem [] items = parent.getItems ();
-			for (int i=0; i<items.length; i++) {
-				MenuItem item = items [i];
+			for (MenuItem item : parent.getItems ()) {
 				if (item.image != null) {
 					Rectangle rect = item.image.getBoundsInPixels ();
 					width = Math.max (width, rect.width);
